# Cloudron Shared Storage Setup

## Popis
Tento repozitář obsahuje návod, jak správně naformátovat a připojit ext4 disk pro sdílení mezi více aplikacemi v prostředí Cloudron. Tento proces zahrnuje formátování disku, připojení, nastavení oprávnění a automatizaci připojování při startu systému.

## Obsah
- [Požadavky](#požadavky)
- [Krok 1: Přeformátování disku na ext4](#krok-1-přeformátování-disku-na-ext4)
- [Krok 2: Vytvoření připojovacího bodu](#krok-2-vytvoření-připojovacího-bodu)
- [Krok 3: Připojení disku](#krok-3-připojení-disku)
- [Krok 4: Automatické připojení při startu systému](#krok-4-automatické-připojení-při-startu-systému)
- [Krok 5: Nastavení oprávnění pro sdílení](#krok-5-nastavení-oprávnění-pro-sdílení)
- [Krok 6: Ověření správného nastavení](#krok-6-ověření-správného-nastavení)

## Požadavky
- Přístup k terminálu na serveru s Cloudronem
- Administrátorská práva
- Znalost správné identifikace disků a oddílů (např. pomocí příkazu `lsblk`)

## Krok 1: Přeformátování disku na ext4
Pro naformátování disku `sdb1` na ext4 použijte následující příkaz:
```bash
mkfs.ext4 /dev/sdb1
```

> Pozor: Tento krok smaže všechna data na disku sdb1. Ujistěte se, že pracujete se správným diskem.

## Krok 2: Vytvoření připojovacího bodu

Vytvořte nový připojovací bod pro disk, například /mnt/storage:

```bash
mkdir /mnt/storage
```

## Krok 3: Připojení disku

Připojte disk sdb1 na nově vytvořenou složku:

```bash
mount /dev/sdb1 /mnt/storage
```
## Krok 4: Automatické připojení při startu systému

Chcete-li, aby se disk připojoval automaticky při startu systému, upravte soubor /etc/fstab a přidejte následující řádek:

```bash
/dev/sdb1  /mnt/storage  ext4  defaults  0  2
```
Poté otestujte správnost konfigurace:

```bash
mount -a
```

## Krok 5: Nastavení oprávnění pro sdílení

Pro sdílení disku mezi aplikacemi nastavte oprávnění pro skupinu media. To zajistí, že soubory vytvořené v tomto adresáři budou automaticky sdíleny mezi aplikacemi.

Nastavte cestu k připojenému adresáři:

```bash
export MOUNT_DIR=/mnt/storage
```

Nastavte oprávnění:

```bash
chmod 777 $MOUNT_DIR
chgrp media $MOUNT_DIR
chmod g+s $MOUNT_DIR
setfacl -d -m g::rwx $MOUNT_DIR
setfacl -d -m o::rx $MOUNT_DIR
```

## Krok 6: Ověření správného nastavení

Vytvořte testovací soubor a ověřte, zda má správná oprávnění:
```bash
touch $MOUNT_DIR/test-file
ls -l $MOUNT_DIR/test-file
```

Očekávaný výstup:

```bash
-rw-rw-r-- 1 root media 0 Sep 14 10:00 /mnt/storage/test-file
```
## Závěr

Tento návod vám pomůže s formátováním, připojením a správným nastavením ext4 disku pro sdílení mezi více aplikacemi v Cloudronu. Díky správnému nastavení oprávnění bude sdílení mezi aplikacemi hladké a bezpečné.

